@@ -22,10 +22,9 @@ pub struct ItemsController {
 
 impl ItemsController {
     /// Create a new items controller instance
-    pub fn new(item_list: Arc<Mutex<ItemList>>, max_resolution: (u32, u32)) -> Self {
+    pub fn new(item_list: Arc<Mutex<ItemList>>) -> Self {
         let mut image_cache = image_cache::ImageCache::new();
-
-        image_cache.restrict_size(max_resolution.0, max_resolution.1);
+        image_cache.restrict_size(1600, 1000);
 
         Self {
             item_list,
@@ -178,6 +177,16 @@ impl ItemsController {
         list_len
     }
 
+    /// Gets the date string for an image
+    pub fn get_date_string(&self, local_index: i32) -> slint::SharedString {
+        let item_list = self.item_list.lock().unwrap();
+        let item = &item_list.items[local_index as usize];
+        let date = chrono::NaiveDateTime::from_timestamp(item.get_timestamp(), 0)
+            .format("%Y-%m-%d")
+            .to_string();
+        slint::SharedString::from(date)
+    }
+
     /// Gets the image for an item
     /// This function returns either a cached image or a loading image while the real image is being loaded
     /// in the background. As soon as the process finishes, the image is displayed.
@@ -346,7 +355,7 @@ mod tests {
     #[test]
     fn test_populate() {
         let item_list = Arc::new(Mutex::new(ItemList::new()));
-        let mut items_controller = ItemsController::new(item_list.clone(), (0, 0));
+        let mut items_controller = ItemsController::new(item_list.clone());
         let mut filters = build_filters();
         {
             let mut item_list = item_list.lock().unwrap();
@@ -398,7 +407,7 @@ mod tests {
     #[test]
     fn test_take_over() {
         let item_list = Arc::new(Mutex::new(ItemList::new()));
-        let mut items_controller = ItemsController::new(item_list.clone(), (0, 0));
+        let mut items_controller = ItemsController::new(item_list.clone());
         let window = ImageSieve::new();
         let window_weak = window.as_weak();
         let filters = build_filters();
@@ -435,7 +444,7 @@ mod tests {
     #[test]
     fn test_select_item() {
         let item_list = Arc::new(Mutex::new(ItemList::new()));
-        let mut items_controller = ItemsController::new(item_list.clone(), (0, 0));
+        let mut items_controller = ItemsController::new(item_list.clone());
         let window = ImageSieve::new();
         let window_weak = window.as_weak();
         let filters = build_filters();
@@ -475,7 +484,7 @@ mod tests {
     #[test]
     fn test_update_list() {
         let item_list = Arc::new(Mutex::new(ItemList::new()));
-        let mut items_controller = ItemsController::new(item_list.clone(), (0, 0));
+        let mut items_controller = ItemsController::new(item_list.clone());
         assert!(!items_controller.update_list_model());
         let filters = build_filters();
         {
